import { Image, StyleSheet, Text, TouchableOpacity, View } from 'react-native'
import React, { useState } from 'react'
import { navigateToListViewPage, useConstructor } from '../../../utils/functions'
import { getCategories } from '../../../api/data'
import fonts from '../../../constants/fonts'
import colors from '../../../constants/colors'
import { horizontalScale, moderateScale, verticalScale } from '../../../constants/metrics'
import { BASE_URL } from '../../../api/urls'
import LoadingScreen from './LoadingScreen'

const CategorySearchSection = props => {

    const {
        navigation,
        route
    } = props

    const [categories, setCategories] = useState(null)

    const fetchCategories = () => {
        getCategories().then(res => setCategories(res.data.body.results)).catch(err => console.log(err))
    }

    useConstructor(() => {
        fetchCategories()
    })

    const styles = StyleSheet.create({
        sectionHeader: {
            fontFamily: fonts.type.semibold,
            color: colors().recessive,
            paddingHorizontal: horizontalScale(16),


        },
        categoryContainer: {
            padding: verticalScale(16),
            flexDirection: 'row',
            flexWrap: 'wrap',
            gap: moderateScale(16),
        },
        category: {
            height: verticalScale(110),
            width: 170,
            backgroundColor: colors().secondaryColor,
            borderRadius: moderateScale(8),
            padding: moderateScale(10),
            alignItems: 'center',
            justifyContent: 'center',
            gap: verticalScale(16)
        },
        categoryIcon: {
            height: moderateScale(36),
            width: moderateScale(36),
            tintColor: colors().white
        },
        categoryText: {
            fontFamily: fonts.type.semibold,
            color: colors().white,
            fontSize: moderateScale(14),
            textAlign: 'right'
        },
    })

    return (
        <View>
            <Text style={styles.sectionHeader}>Browse by Categories</Text>
            <View style={styles.categoryContainer}>
                {
                    categories !== null ?
                        categories.length > 0 ?
                            categories.map((item) =>
                                <TouchableOpacity onPress={() => navigateToListViewPage(navigation, "category", item.heading.name)}>
                                    <View style={styles.category}>
                                        <Image source={{ uri: BASE_URL + "/" + item.heading.icon }} style={styles.categoryIcon} />
                                        <Text style={styles.categoryText}>{item.heading.name}</Text>
                                    </View>
                                </TouchableOpacity>

                            ) : <></>
                        : <LoadingScreen containerHeight={verticalScale(240)}/>
                }

            </View>
        </View>
    )
}

export default CategorySearchSection
