import { StyleSheet, Text, TouchableOpacity, View } from 'react-native'
import React, { useState } from 'react'
import { horizontalScale, moderateScale, verticalScale } from '../../../constants/metrics'
import colors from '../../../constants/colors'
import fonts from '../../../constants/fonts'
import { navigateToArticle, useConstructor } from '../../../utils/functions'
import { getTrendingNews } from '../../../api/data'
import { PAGINATE_BY } from '../../../api/urls'
import { List } from 'react-native-paper'
import IonIcon from 'react-native-vector-icons/Ionicons'
import LoadingScreen from './LoadingScreen'

const RecentSearchesSection = props => {

    const [recentSearches, setRecentSearches] = useState(null)
    const {
        navigation,
        route
    } = props

    const getRecentSearches = () => {
        getTrendingNews().then(res => setRecentSearches(res.data.body.results.slice(0, PAGINATE_BY))).catch(err => console.error(err))
    }

    useConstructor(() => {
        getRecentSearches()
    })

    const styles = StyleSheet.create({
        sectionHeader: {
            fontFamily: fonts.type.semibold,
            color: colors().recessive,
            paddingHorizontal: horizontalScale(16),
        },
        categoryContainer: {
            padding: verticalScale(16),
            flexDirection: 'row',
            flexWrap: 'wrap',
            gap: moderateScale(16),
        },
    })

    return (
        <View>
            <Text style={styles.sectionHeader}>Recent Searches</Text>
            <View style={[styles.categoryContainer, { gap: 0 }]}>
                {
                    recentSearches !== null ?
                        recentSearches.length > 0 ?
                            recentSearches.map(item => {
                                const newsTag = item.articles[0]
                                return <TouchableOpacity onPress={() => navigateToArticle(navigation, newsTag.id, newsTag.slug)}>
                                    <List.Item
                                        title={newsTag.title}
                                        titleStyle={{ fontFamily: fonts.type.regular, fontSize: moderateScale(12), color: colors().grayShade_200 }}
                                        style={{ paddingVertical: 0 }}
                                        left={() => <IonIcon name="trending-up" color={colors().grayShade_300} size={moderateScale(16)} />}

                                    />
                                </TouchableOpacity>
                            }) : <></> : <LoadingScreen containerHeight={verticalScale(240)}/>
                }
            </View>
        </View>
    )
}

export default RecentSearchesSection

